==> MK-portable-3.5.zip: MK-Portable-3.5/MK/xulsword/defaults/preferences/prefs.js <==
pref("extensions.xulsword.BuildID", "130115_292P");
pref("extensions.xulsword.Cross-references", "On");
pref("extensions.xulsword.DefaultCK", "spirit");
pref("extensions.xulsword.DefaultVersion", "none");
pref("extensions.xulsword.Dictionary", "On");
pref("extensions.xulsword.DontReadReferenceBible", false);
pref("extensions.xulsword.DontShowExceptionDialog", false);
pref("extensions.xulsword.EngineVersion", "1.6.2");
pref("extensions.xulsword.Footnotes", "On");
pref("extensions.xulsword.Headings", "On");
pref("extensions.xulsword.Hebrew Cantillation", "On");
pref("extensions.xulsword.Hebrew Vowel Points", "On");
pref("extensions.xulsword.HelpEmailAddress", "gpl.programs.info@gmail.com");
pref("extensions.xulsword.HideDisabledBooks", false);
pref("extensions.xulsword.HideDisabledViewMenuItems", false);
pref("extensions.xulsword.Location", "Matt.1.1");
pref("extensions.xulsword.MaximizeNoteBox1", false);
pref("extensions.xulsword.MaximizeNoteBox2", false);
pref("extensions.xulsword.MaximizeNoteBox3", false);
pref("extensions.xulsword.MinUIversion", "3.5");
pref("extensions.xulsword.MinXSMversion", "1.0");
pref("extensions.xulsword.Morphological Tags", "On");
pref("extensions.xulsword.Name", "MK");
pref("extensions.xulsword.ShowCrossrefsAtBottom", false);
pref("extensions.xulsword.ShowFootnotesAtBottom", true);
pref("extensions.xulsword.ShowUserNotesAtBottom", true);
pref("extensions.xulsword.Strong's Numbers", "On");
pref("extensions.xulsword.User Notes", "On");
pref("extensions.xulsword.Vendor", "IBT");
pref("extensions.xulsword.Verse Numbers", "On");
pref("extensions.xulsword.Version", "3.5");
pref("extensions.xulsword.Words of Christ in Red", "On");
pref("extensions.xulsword.hideUntilModuleInstalled.ct", true);
pref("extensions.xulsword.hideUntilModuleInstalled.kum", true);
pref("extensions.xulsword.hideUntilModuleInstalled.ky", true);
pref("extensions.xulsword.hideUntilModuleInstalled.ky-ar", true);
pref("extensions.xulsword.hideUntilModuleInstalled.uz", true);
pref("extensions.xulsword.hideUntilModuleInstalled.uz-lat", true);
pref("extensions.xulsword.w1.hidden", "TR;HEB;StrongsGreek;StrongsHebrew;Robinson;");
pref("extensions.xulsword.w2.hidden", "TR;HEB;StrongsGreek;StrongsHebrew;Robinson;");
pref("extensions.xulsword.w3.hidden", "TR;HEB;StrongsGreek;StrongsHebrew;Robinson;");
pref("intl.locale.matchOS", false);
pref("toolkit.defaultChromeURI", "chrome://xulsword/content/startup/splash.xul");

==> MK-portable-3.6.zip: MK-Portable-3.6/MK/xulsword/defaults/preferences/prefs.js <==
pref("extensions.xulsword.BuildID", "131008_439P");
pref("extensions.xulsword.Cross-references", "On");
pref("extensions.xulsword.DefaultCK", "spirit");
pref("extensions.xulsword.DefaultVersion", "none");
pref("extensions.xulsword.DontReadReferenceBible", false);
pref("extensions.xulsword.DontShowExceptionDialog", false);
pref("extensions.xulsword.EngineVersion", "1.7");
pref("extensions.xulsword.Footnotes", "On");
pref("extensions.xulsword.Headings", "On");
pref("extensions.xulsword.Hebrew Cantillation", "On");
pref("extensions.xulsword.Hebrew Vowel Points", "On");
pref("extensions.xulsword.HelpEmailAddress", "gpl.programs.info@gmail.com");
pref("extensions.xulsword.HideDisabledBooks", false);
pref("extensions.xulsword.HideDisabledViewMenuItems", false);
pref("extensions.xulsword.Location", "Matt.1.1");
pref("extensions.xulsword.MaximizeNoteBox1", false);
pref("extensions.xulsword.MaximizeNoteBox2", false);
pref("extensions.xulsword.MaximizeNoteBox3", false);
pref("extensions.xulsword.MinUIversion", "3.6");
pref("extensions.xulsword.MinXSMversion", "1.0");
pref("extensions.xulsword.Morphological Tags", "On");
pref("extensions.xulsword.Name", "MK");
pref("extensions.xulsword.Reference Material Links", "On");
pref("extensions.xulsword.ShowCrossrefsAtBottom", false);
pref("extensions.xulsword.ShowFootnotesAtBottom", true);
pref("extensions.xulsword.ShowUserNotesAtBottom", true);
pref("extensions.xulsword.Strong's Numbers", "On");
pref("extensions.xulsword.User Notes", "On");
pref("extensions.xulsword.Vendor", "IBT");
pref("extensions.xulsword.Verse Numbers", "On");
pref("extensions.xulsword.Version", "3.6");
pref("extensions.xulsword.Words of Christ in Red", "On");
pref("extensions.xulsword.w1.hidden", "TR;HEB;StrongsGreek;StrongsHebrew;Robinson;");
pref("extensions.xulsword.w2.hidden", "TR;HEB;StrongsGreek;StrongsHebrew;Robinson;");
pref("extensions.xulsword.w3.hidden", "TR;HEB;StrongsGreek;StrongsHebrew;Robinson;");
pref("intl.locale.matchOS", false);
pref("toolkit.defaultChromeURI", "chrome://xulsword/content/startup/splash.xul");
pref("ui.use_unity_menubar", false);
